package com.zyc.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zyc.system.mapper.BigDataComputeServicesMapper;
import com.zyc.system.domain.BigDataComputeServices;
import com.zyc.system.service.IBigDataComputeServicesService;

/**
 * 大数据计算服务Service业务层处理
 * 
 * @author zyc
 * @date 2024-12-26
 */
@Service
public class BigDataComputeServicesServiceImpl implements IBigDataComputeServicesService 
{
    @Autowired
    private BigDataComputeServicesMapper bigDataComputeServicesMapper;

    /**
     * 查询大数据计算服务
     * 
     * @param id 大数据计算服务主键
     * @return 大数据计算服务
     */
    @Override
    public BigDataComputeServices selectBigDataComputeServicesById(Integer id)
    {
        return bigDataComputeServicesMapper.selectBigDataComputeServicesById(id);
    }

    /**
     * 查询大数据计算服务列表
     * 
     * @param bigDataComputeServices 大数据计算服务
     * @return 大数据计算服务
     */
    @Override
    public List<BigDataComputeServices> selectBigDataComputeServicesList(BigDataComputeServices bigDataComputeServices)
    {
        return bigDataComputeServicesMapper.selectBigDataComputeServicesList(bigDataComputeServices);
    }

    /**
     * 新增大数据计算服务
     * 
     * @param bigDataComputeServices 大数据计算服务
     * @return 结果
     */
    @Override
    public int insertBigDataComputeServices(BigDataComputeServices bigDataComputeServices)
    {
        return bigDataComputeServicesMapper.insertBigDataComputeServices(bigDataComputeServices);
    }

    /**
     * 修改大数据计算服务
     * 
     * @param bigDataComputeServices 大数据计算服务
     * @return 结果
     */
    @Override
    public int updateBigDataComputeServices(BigDataComputeServices bigDataComputeServices)
    {
        return bigDataComputeServicesMapper.updateBigDataComputeServices(bigDataComputeServices);
    }

    /**
     * 批量删除大数据计算服务
     * 
     * @param ids 需要删除的大数据计算服务主键
     * @return 结果
     */
    @Override
    public int deleteBigDataComputeServicesByIds(Integer[] ids)
    {
        return bigDataComputeServicesMapper.deleteBigDataComputeServicesByIds(ids);
    }

    /**
     * 删除大数据计算服务信息
     * 
     * @param id 大数据计算服务主键
     * @return 结果
     */
    @Override
    public int deleteBigDataComputeServicesById(Integer id)
    {
        return bigDataComputeServicesMapper.deleteBigDataComputeServicesById(id);
    }
}
